@@ -28,7 +28,7 @@ our @EXPORT_OK = ( @{ $EXPORT_TAGS{'all'} } );
 
 #our @EXPORT = qw();
 
-our $VERSION = '1.00';
+our $VERSION = '1.00_01';
 
 require XSLoader;
 XSLoader::load('POSIX::Run::Capture', $VERSION);
@@ -109,8 +109,8 @@ Creates a new capture object. There are three possible invocation modes.
   new POSIX::Run::Capture(argv => [ $command, @args ],
  			  program => $prog,
 			  stdin => $fh_or_string,
-			  stdout => sub { ... },
-			  stderr => sub { ... },
+			  stdout => $ref_or_string,
+			  stderr => $ref_or_string,
 			  timeout => $n)
 
 When named arguments are used, the following keywords are allowed:
@@ -131,7 +131,7 @@ Sets the pathname of binary file to run.
 Supplies standard input for the command. The argument can be a string or
 a file handle.
 
-=item B<stdout>
+=item B<stdout> =E<gt> I<$coderef>
 
 Sets the I<line monitor> function for standard output. Line monitor is
 invoked each time a complete line is read, or the EOF is hit on the standard
@@ -145,10 +145,20 @@ following example monitor function prints its argument to STDOUT:
 
 Notice that the last line read can lack the teminating newline character.
 
-=item B<stderr>
+=item B<stdout> =E<gt> I<FH>
 
-Sets the I<line monitor> function for standard error stream. See the
-description above.
+Capture standard output and write it to the file handle I<FH>.    
+    
+=item B<stdout> =E<gt> I<NAME>
+
+Capture standard output and write it to the file I<NAME>.  If the file
+exists, it will be truncated.    
+
+=item B<stderr> =E<gt> I<$arg>
+
+Sets the I<line monitor> function for standard error or redirects it to
+the file handle or file, depending on the type of I<$arg>.  See the
+description of B<stdout> above.
 
 =item B<timeout>
 
